import { LoadedConfigSelectors } from "@smithy/node-config-provider";
export declare const UA_APP_ID_ENV_NAME = "AWS_SDK_UA_APP_ID";
export declare const UA_APP_ID_INI_NAME = "sdk_ua_app_id";
export declare const NODE_APP_ID_CONFIG_OPTIONS: LoadedConfigSelectors<
  string | undefined
>;
